@@ -1,22 +1,39 @@
 #!/usr/bin/env python
 from __future__ import with_statement
-import json, sys, os, subprocess
+from os import environ
+import json
+import yaml
 
 class ConfigoNotExistingKeyError(Exception): pass
 
 class Configo():
     def __init__(self):
-        self.tmp_conf_name = os.environ.get('CONFIGO_CONF', None)
+        self.tmp_conf_name = environ.get('CONFIGO_CONF', None)
 
     def load_config(self, config_path):
         with open(config_path) as config:
             config_content = config.read()
             return config_content
 
-    def get_key(self, config_path, keyname):
-        config_content = self.load_config(config_path)
-        json_object = json.loads(config_content)
+    def config_type(self, config_path):
+        return config_path.split('.')[-1]
 
+    def config_object(self, config_path):
+        config_content = self.load_config(config_path)
+        config_type = self.config_type(config_path)
+
+        result = ''
+
+        if config_type == 'json':
+            result = json.loads(config_content)
+        elif config_type == 'xml':
+            raise NotImplementedError
+        elif config_type == 'yaml':
+            result = yaml.load(config_content)
+
+        return result
+
+    def keyname(self, keyname, config_object):
         splited_key = keyname.split('.')
 
         result = ''
@@ -24,13 +41,12 @@ class Configo():
 
         for item in splited_key:
             if iteration == 0:
-                result = result = self.get_value(json_object, item)
+                result = self.get_value(config_object, item)
             else:
                 result = self.get_value(result, item)
 
             iteration += 1
-
-        return str(result)
+        return result
 
     def get_value(self, obj, item):
         result = ''
@@ -42,4 +58,11 @@ class Configo():
         except (KeyError, IndexError):
             raise ConfigoNotExistingKeyError()
 
-        return result
\ No newline at end of file
+        return result
+
+    def get_key(self, config_path, keyname):
+
+        config_object = self.config_object(config_path)
+        the_key = self.keyname(keyname, config_object)
+
+        return str(the_key)
